Stan Math Library: stan/math/prim/scal/fun/lub_constrain.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
lub_constrain.hpp File Reference
`#include <stan/math/prim/scal/err/check_less.hpp>`
`#include <stan/math/prim/scal/fun/lb_constrain.hpp>`
`#include <stan/math/prim/scal/fun/ub_constrain.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <cmath>`
`#include <limits>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , typename TL , typename TU >
boost::math::tools::promote_args< T, TL, TU >::type | stan::math::lub_constrain (const T x, TL lb, TU ub)
| Return the lower- and upper-bounded scalar derived by transforming the specified free scalar given the specified lower and upper bounds. More...
template<typename T , typename TL , typename TU >
boost::math::tools::promote_args< T, TL, TU >::type | stan::math::lub_constrain (const T x, const TL lb, const TU ub, T &lp)
| Return the lower- and upper-bounded scalar derived by transforming the specified free scalar given the specified lower and upper bounds and increment the specified log probability with the log absolute Jacobian determinant. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.